### dnsperf

loglevel is warn/info.

#### for 2 udp upstream

max qps is 1500.

Greendns cpu is near 100%.

#### for 1 udp upstream and 1 tcp upstream(dnsmasq)

max qps is 1100.

Greendns cpu is near 100%. Dnsmasq cpu is about 70%.
